Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2967)

Unified Diff: chrome/browser/ui/autofill/autofill_dialog_view_delegate.h

Issue 55243005: Implement learn more bubble on views. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: merge Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
diff --git a/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h b/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
index 2de200e7909ca916f31dc79de1e4535f8ef37e4a..f341dbc505025cb572e4d859009a59efada8ec10 100644
--- a/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
+++ b/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
@@ -51,7 +51,7 @@ class AutofillDialogViewDelegate {
virtual string16 CancelButtonText() const = 0;
virtual string16 ConfirmButtonText() const = 0;
virtual string16 SaveLocallyText() const = 0;
- virtual string16 SaveLocallyTooltip() const = 0;
+ virtual string16 SaveLocallyLearnMoreText() const = 0;
virtual string16 LegalDocumentsText() = 0;
// State ---------------------------------------------------------------------
@@ -135,8 +135,9 @@ class AutofillDialogViewDelegate {
// rest of the fields in a section.
virtual bool FieldControlsIcons(ServerFieldType type) const = 0;
- // Returns a tooltip for the given field, or an empty string if none exists.
- virtual string16 TooltipForField(ServerFieldType type) const = 0;
+ // Returns the "learn more" text for the given field, or an empty string if
+ // none exists.
+ virtual string16 LearnMoreTextForField(ServerFieldType type) const = 0;
// Whether a particular DetailInput in |section| should be edited or not.
virtual bool InputIsEditable(const DetailInput& input,

Powered by Google App Engine
This is Rietveld 408576698